@@ -32,13 +32,13 @@
 #' @import rgl
 #' @importFrom graphics lines plot points text
 
-polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
+polyplot <- function(X=NULL,L=NULL,Wk=NULL,nobj=3){
   
   
   if (nobj==3){
     
     #rankings in the polytope
-    ranks=rbind(
+    ranks<-rbind(
       c(1,2,3),
       c(1,2,2),
       c(1,3,2),
@@ -54,14 +54,14 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       c(1,1,1)
     )
     
-    if (is.null(L)){
-      rr=labels(ranks,3,labs=2)
+    if (is(L,"NULL")){
+      rr<-labelsn(ranks,3,labs=2)
     } else {
-      rr=labels(ranks,3,L,labs=1)
+      rr<-labelsn(ranks,3,L,labs=1)
     }
     
     #coordinates of polytope
-    coord=rbind(
+    coord<-rbind(
       c(  0.000000e+00,  4.082483e-01), #ABC
       c(  1.767767e-01,  3.061862e-01), #A(BC)
       c(  3.535534e-01,  2.041241e-01), #ACB
@@ -85,18 +85,18 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     lines(c(coord[4,1],coord[10,1]),c(coord[4,2],coord[10,2]),lty=2)
     lines(c(coord[6,1],coord[12,1]),c(coord[6,2],coord[12,2]),lty=2)
     
-    t1=c(1,2,3,11,12,13)
-    t2=c(4,10)
-    t3=c(5,6,7,8,9)
+    t1<-c(1,2,3,11,12,13)
+    t2<-c(4,10)
+    t3<-c(5,6,7,8,9)
     tcoord=coord #text coordinates
-    tcoord[t1,2]=tcoord[t1,2]+0.1
-    tcoord[t3,2]=tcoord[t3,2]-0.1
-    tcoord[t2[1],1]=tcoord[t2[1],1]+0.1
-    tcoord[t2[2],1]=tcoord[t2[2],1]-0.1
+    tcoord[t1,2]<-tcoord[t1,2]+0.1
+    tcoord[t3,2]<-tcoord[t3,2]-0.1
+    tcoord[t2[1],1]<-tcoord[t2[1],1]+0.1
+    tcoord[t2[2],1]<-tcoord[t2[2],1]-0.1
     #text(tcoord,rr)
     
-    if (is.null(X)){
-      indplot=matrix(1:13,ncol=1)
+    if (is(X,"NULL")){
+      indplot<-matrix(1:13,ncol=1)
     } else {
       
       #o = outer(seq_len(nrow(X)), seq_len(nrow(ranks)), Vectorize(
@@ -104,15 +104,15 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       #))
       #ranksinplot=ranks[apply(o, 2, any),]
       
-      o2 = outer(seq_len(nrow(ranks)), seq_len(nrow(X)), Vectorize(
+      o2 <- outer(seq_len(nrow(ranks)), seq_len(nrow(X)), Vectorize(
         function(i, j) which(all(ranks[i,]==X[j,]))
       ))
       
-      indexing=o2==1
+      indexing<-o2==1
       #print(indexing)
-      indexing[indexing==TRUE]=1
-      indexing[is.na(indexing)]=0
-      indplot=which(rowSums(indexing)==1)
+      indexing[indexing==TRUE]<-1
+      indexing[is.na(indexing)]<-0
+      indplot<-which(rowSums(indexing)==1)
       #print(indplot)
     }
     
@@ -121,26 +121,26 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     # }
     #X
     #put labels to rankings
-    if (is.null(Wk)){
+    if (is(Wk,"NULL")){
       
       points(coord[indplot,1],coord[indplot,2],pch=16,cex=0.8,col="blue")
       
     }else{
       
-      if (is.numeric(Wk)) {
+      if (is(Wk,"numeric")) {
         
-        Wk=matrix(Wk,ncol=1)
+        Wk<-matrix(Wk,ncol=1)
         
       }
       
-      idwk=matrix(0,nrow(X),1)
-      counter=0
+      idwk<-matrix(0,nrow(X),1)
+      counter<-0
       for (i in 1:13){
         for (j in 1:nrow(X)){
-          check=sum(pos=X[j,]==ranks[i,])
+          check<-sum(pos=X[j,]==ranks[i,])
           if (check==3){
-            counter=counter+1
-            idwk[counter]=j
+            counter<-counter+1
+            idwk[counter]<-j
             break}
         }
       }
@@ -161,7 +161,7 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     #---------------------------------------------
     
     #-Exagon A first
-    E1=rbind(
+    E1<-rbind(
       c(0.5,  0.5,  1.4142135),  #   ...    %%'A B C D'     [1 2 3 4]   1
       c(1.0,  1.0,  0.70710677), #  ...    %%'A C B D'     [1 3 2 4]   2
       c(1.5,  0.5,  0.0), #                 %%'A C D B'     [1 4 2 3]   3
@@ -171,8 +171,8 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     )
     
     
-    MA=apply(E1,2,mean) #  center of exagon A   A(BCD)  [1 2 2 2]  7
-    E1T=rbind(
+    MA<-apply(E1,2,mean) #  center of exagon A   A(BCD)  [1 2 2 2]  7
+    E1T<-rbind(
       c(1.2500,    0.7500,    0.3536),#;...  %% 'A C {BD}'   [1 3 2 3]   8
       c(0.7500,   -0.7500,    1.0607),#;...  %% 'A {BD} C'   [1 2 3 2]   9
       c(0.5000,         0,    1.4142),#;...  %% 'A B {CD}'   [1 2 3 3]   10
@@ -183,14 +183,14 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     
     
     
-    ranksA=rbind(
+    ranksA<-rbind(
       c(1,2,3,4),c(1,3,2,4),c(1,4,2,3),c(1,4,3,2),c(1,3,4,2),c(1,2,4,3),c(1,2,2,2),
       c(1,3,2,3),c(1,2,3,2),c(1,2,3,3),c(1,3,2,2),c(1,3,3,2),c(1,2,2,3)
     )
     
     #---------------------------------------------
     #-Exagon B first
-    E2=rbind(
+    E2<-rbind(
       c(-1.5, -0.5,  0.0),#        ...    %%'B D C A'     [4 1 3 2]   14
       c(-1.5,  0.5,  0.0),#        ...    %%'B C D A'     [4 1 2 3]   15 
       c(-1.0,  1.0,  0.70710677),# ...    %%'B C A D'     [3 1 2 4]   16 
@@ -199,9 +199,9 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       c(-1.0, -1.0,  0.70710677)# ...    %%'B D A C'     [3 1 4 2]   19
     )
     
-    MB=apply(E2,2,mean) #center of exagon B  B(ACD)        [2 1 2 2]  20
+    MB<-apply(E2,2,mean) #center of exagon B  B(ACD)        [2 1 2 2]  20
     
-    E2T=rbind(
+    E2T<-rbind(
       c(-0.5000,         0,    1.4142),#; ... %% 'B A {CD}'   [2 1 3 3]   21
       c(-1.5000,         0,         0),#;...  %% 'B {CD} A'   [3 1 2 2]   22
       c(-1.2500,    0.7500,    0.3536),#;...  %% 'B C {AD}'   [3 1 2 3]   23
@@ -211,7 +211,7 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     )
     
     
-    ranksB=rbind(
+    ranksB<-rbind(
       c(4,1,3,2),c(4,1,2,3),c(3,1,2,4),c(2,1,3,4),c(2,1,4,3),c(3,1,4,2),c(2,1,2,2),
       c(2,1,3,3),c(3,1,2,2),c(3,1,2,3),c(2,1,3,2),c(3,1,3,2),c(2,1,2,3)
     )
@@ -221,7 +221,7 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     #-------------------------------------------------
     #exagon C first
     
-    E3=rbind(
+    E3<-rbind(
       c(-1.0,  1.0, -0.70710677),# ...    %%'C B D A'     [4 2 1 3]   27
       c(-0.5,  0.5, -1.4142135),#  ...    %%'C D B A'     [4 3 1 2]   28
       c(0.5,  0.5, -1.4142135),#   ...    %%'C D A B'     [3 4 1 2]   29
@@ -230,9 +230,9 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       c(-0.5,  1.5,  0.0) #        ...    %%'C B A D'     [3 2 1 4]   32
     )
     
-    MC=apply(E3,2,mean) #center of exagon C  C(ABD)        [2 2 1 2] 33
+    MC<-apply(E3,2,mean) #center of exagon C  C(ABD)        [2 2 1 2] 33
     
-    E3T=rbind(
+    E3T<-rbind(
       c(0,    0.5000,   -1.4142),      #;...  %% 'C D {AB}'   [3 3 1 2]   34
       c(0,    1.5000,         0),      #;...  %% 'C {AB} D'   [2 2 1 3]   35
       c(0.7500,    1.2500,   -0.3536), #;...  %% 'C A {BD}'   [2 3 1 3]   36
@@ -241,7 +241,7 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       c(-0.7500,    1.2500,   -0.3536) #;...  %% 'C B {AD}'   [3 2 1 3]   39
     )
     
-    ranksC=rbind(c(4,2,1,3),c(4,3,1,2),c(3,4,1,2),c(2,4,1,3),c(2,3,1,4),c(3,2,1,4),c(2,2,1,2),
+    ranksC<-rbind(c(4,2,1,3),c(4,3,1,2),c(3,4,1,2),c(2,4,1,3),c(2,3,1,4),c(3,2,1,4),c(2,2,1,2),
                  c(3,3,1,2),c(2,2,1,3),c(2,3,1,3),c(3,2,1,2),c(2,3,1,2),c(3,2,1,3)             
     )
     
@@ -249,7 +249,7 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     #--------------------------------------
     #exagon D first
     
-    E4=rbind(
+    E4<-rbind(
       c(-1.0, -1.0, -0.70710677),# ...    %%'D B C A'     [4 2 3 1]   40
       c(-0.5, -0.5, -1.4142135),#  ...    %%'D C B A'     [4 3 2 1]   41
       c(0.5, -0.5, -1.4142135),#   ...    %%'D C A B'     [3 4 2 1]   42
@@ -258,9 +258,9 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       c(-0.5, -1.5,  0.0) #        ...    %%'D B A C'     [3 2 4 1]   45
     )
     
-    MD=apply(E4,2,mean) #center of exagon D  D(ABC)        [2 2 2 1]  46
+    MD<-apply(E4,2,mean) #center of exagon D  D(ABC)        [2 2 2 1]  46
     
-    E4T=rbind(
+    E4T<-rbind(
       c(0,   -0.5000,   -1.4142),      #;...  %% 'D C {AB}'   [3 3 2 1]   47
       c(0,   -1.5000,         0),      #;...  %% 'D {AB} C'   [2 2 3 1]   48
       c(-0.7500,   -1.2500,   -0.3536),#;...  %% 'D B {AC}'   [3 2 3 1]   49
@@ -269,13 +269,13 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       c(0.7500,   -1.2500,   -0.3536)  #;...  %% 'D A {BC}'   [2 3 3 1]   52
     )
     
-    ranksD=rbind(c(4,2,3,1),c(4,3,2,1),c(3,4,2,1),c(2,4,3,1),c(2,3,4,1),c(3,2,4,1),c(2,2,2,1),
+    ranksD<-rbind(c(4,2,3,1),c(4,3,2,1),c(3,4,2,1),c(2,4,3,1),c(2,3,4,1),c(3,2,4,1),c(2,2,2,1),
                  c(3,3,2,1),c(2,2,3,1),c(3,2,3,1),c(2,3,2,1),c(3,2,2,1),c(2,3,3,1)             
     )
     
     
     #squares----------------------------------------------------------
-    ESQ=rbind(
+    ESQ<-rbind(
       c(0,    0.5000,    1.4142), #      ; ... %% '{AB} C D'   [1 1 2 3]   53
       c(0,   -0.5000,    1.4142), #      ; ... %% '{AB} D C'   [1 1 3 2]   54
       c(-0.5000,         0,   -1.4142), # ;...  %% '{CD} B A'   [3 2 1 1]   55
@@ -290,22 +290,22 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
       c(-0.7500,   -1.2500,    0.3536) #  ;...  %% '{BD} A C'   [2 1 3 1]   64
     )
     
-    ranksSQ=rbind(c(1,1,2,3),c(1,1,3,2),c(3,2,1,1),c(2,3,1,1),c(1,3,1,2),c(1,2,1,3),
+    ranksSQ<-rbind(c(1,1,2,3),c(1,1,3,2),c(3,2,1,1),c(2,3,1,1),c(1,3,1,2),c(1,2,1,3),
                   c(3,1,1,2),c(2,1,1,3),c(1,3,2,1),c(1,2,3,1),c(3,1,2,1),c(2,1,3,1)
     )
     
     #------------------------------------------------------------------------
     
-    M_AB_CD=apply(rbind(c(0,0.5,1.4142),c(-0.5,0,1.4142),c(0,-0.5,1.4142),
+    M_AB_CD<-apply(rbind(c(0,0.5,1.4142),c(-0.5,0,1.4142),c(0,-0.5,1.4142),
                         c(0.5,0,1.4142)),2,mean) # '{AB}{CD}'   [1 1 2 2]   65
     
-    M_AC_BD=apply(rbind(c(1.25,0.75,0.3536),c(1.25,0.75,-0.3536),c(0.75,1.25,-0.3536),
+    M_AC_BD<-apply(rbind(c(1.25,0.75,0.3536),c(1.25,0.75,-0.3536),c(0.75,1.25,-0.3536),
                         c(0.75,1.25,0.3536)),2,mean) #'{AC}{BD}'   [1 2 1 2] 66
     
-    M_BC_AD=apply(rbind(c(-0.75,1.25,-0.3536),c(-1.25,0.75,-0.3536),c(-1.25,0.75,0.3536),
+    M_BC_AD<-apply(rbind(c(-0.75,1.25,-0.3536),c(-1.25,0.75,-0.3536),c(-1.25,0.75,0.3536),
                         c(-0.75,1.25,0.3536)),2,mean) # '{BC}{AD}'   [2 1 1 2] 67
     
-    EMID=rbind(M_AB_CD, M_AC_BD, M_BC_AD, M_AB_CD*-1, M_AC_BD*-1, M_BC_AD*-1,MA*-1,MB*-1,MC*-1,MD*-1) 
+    EMID<-rbind(M_AB_CD, M_AC_BD, M_BC_AD, M_AB_CD*-1, M_AC_BD*-1, M_BC_AD*-1,MA*-1,MB*-1,MC*-1,MD*-1) 
     #M_AB_CD*-1 = '{CD}{AB}'   [2 2 1 1] 68
     #M_AC_BD*-1 = '{BD}{AC}'   [2 1 2 1] 69
     #M_BC_AD*-1;= '{AD}{BC}'   [1 2 2 1] 70
@@ -315,21 +315,21 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     #MD*-1;=      '{ABC}D'   [1 1 1 2] 74
     #last =        {ABCD}    [1 1 1 1] 75 
     
-    rankres=rbind(c(1,1,2,2),c(1,2,1,2),c(2,1,1,2),c(2,2,1,1),c(2,1,2,1),
+    rankres<-rbind(c(1,1,2,2),c(1,2,1,2),c(2,1,1,2),c(2,2,1,1),c(2,1,2,1),
                   c(1,2,2,1),c(2,1,1,1),c(1,2,1,1),c(1,1,2,1),c(1,1,1,2),c(1,1,1,1)
     )
     
     
     
     
-    EE=rbind(E1,MA,E1T,E2,MB,E2T,E3,MC,E3T,E4,MD,E4T,ESQ,EMID)
-    coord=rbind(EE,apply(EE,2,mean))
-    ranks=rbind(ranksA,ranksB,ranksC,ranksD,ranksSQ,rankres)
+    EE<-rbind(E1,MA,E1T,E2,MB,E2T,E3,MC,E3T,E4,MD,E4T,ESQ,EMID)
+    coord<-rbind(EE,apply(EE,2,mean))
+    ranks<-rbind(ranksA,ranksB,ranksC,ranksD,ranksSQ,rankres)
     
-    if (is.null(L)){
-      rr=labels(ranks,4,labs=2)
+    if (is(L,"NULL")){
+      rr<-labelsn(ranks,4,labs=2)
     } else {
-      rr=labels(ranks,4,L,labs=1)
+      rr<-labelsn(ranks,4,L,labs=1)
     }
     
     
@@ -417,22 +417,22 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     segments3d(rbind(ESQ[11,],E3T[4,]), lwd=0.5, col = 'gray')
     #-----------------------------
     
-    if (is.null(X)){
-      indplot=matrix(1:75,ncol=1)
+    if (is(X,"NULL")){
+      indplot<-matrix(1:75,ncol=1)
     } else {
       
       
       #ranksinplot=ranks[apply(o, 2, any),]
       
-      o2 = outer(seq_len(nrow(ranks)), seq_len(nrow(X)), Vectorize(
+      o2 <- outer(seq_len(nrow(ranks)), seq_len(nrow(X)), Vectorize(
         function(i, j) which(all(ranks[i,]==X[j,]))
       ))
       
-      indexing=o2==1
+      indexing<-o2==1
       #print(indexing)
-      indexing[indexing==TRUE]=1
-      indexing[is.na(indexing)]=0
-      indplot=which(rowSums(indexing)==1)
+      indexing[indexing==TRUE]<-1
+      indexing[is.na(indexing)]<-0
+      indplot<-which(rowSums(indexing)==1)
       #print(indplot)
       #       ranksinplot=ranks[indplot,]
       #       
@@ -457,19 +457,19 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
     #points(coord[indplot,1],coord[indplot,2],pch=16)
     #points3d(coord[indplot,],col="blue",cex=sqrt(100*((Wk/sum(Wk))/pi)))
     
-    if (is.null(Wk)){
+    if (is(Wk,"NULL")){
       
       spheres3d(coord[indplot,],col="blue",radius=0.02)
       
     } else {
-      idwk=matrix(0,nrow(X),1)
-      counter=0
+      idwk<-matrix(0,nrow(X),1)
+      counter<-0
       for (i in 1:75){
         for (j in 1:nrow(X)){
-          check=sum(pos=X[j,]==ranks[i,])
+          check<-sum(pos=X[j,]==ranks[i,])
           if (check==4){
-            counter=counter+1
-            idwk[counter]=j
+            counter<-counter+1
+            idwk[counter]<-j
             break}
         }
       }
@@ -482,3 +482,71 @@ polyplot = function(X=NULL,L=NULL,Wk=NULL,nobj=3){
            coord[indplot,3]+0.1,rr[indplot,],col=1,cex=0.7)
   }
 }
+
+#--------------------------------------------------------------
+
+labelsn <- function(x, m, label = 1:m, labs ){
+  
+  ## Place labels in a data matrix X of rankings (N judges by M objects)
+  #m is the number of objects
+  #label (optional) is the vector of the objects names
+  #labs = 1 or 2
+  #source('reordering.r')
+  # if the class of the object is different from 'matrix' transform it in 'matrix'
+  if(!is(x,"matrix")){
+    obs <- length(x)
+    XX <- matrix(x, ncol = obs)
+  } else {
+    XX <- x
+  }
+  
+  nj <- nrow(XX)
+  nob <- ncol(XX)
+  
+  ## if length of the object is higher than m, last number is the penalty
+  #if(nob > m){
+  ## if the number of rows is 1 is a vector
+  #  if(nj == 1){
+  #    pens = x[m+1]
+  #    X = matrix(reordering(XX[1:m]), m, ncol = m)
+  #    } else {
+  #    pens = x[,m+1]
+  #    X = t(apply(x, 1, function(g) reordering(g, m)))
+  #    }
+  #} else {
+  X <- XX
+  #}
+  if(labs ==1){
+    let <- label
+  } else if(labs == 2){
+    let <- LETTERS[label]
+  }
+  
+  out <- rep(0, nj)
+  for(i in 1:nj){
+    
+    ord <- rank(X[i,])
+    orders <- tapply(let, ord, sort)
+    
+    names1 <- NULL
+    for(j in 1:length(orders)){
+      if(length(orders[[j]]) > 1){
+        nams <- paste('(', paste(orders[[j]], sep = '', collapse = ' '), ')', sep = '', collapse='')
+      } else {
+        nams <- paste(orders[[j]], collapse = ' ')
+      }
+      names1 <- c(names1, nams)
+    }
+    out[i] <- paste(names1, collapse = ' ' )
+  }
+  out <- matrix(out, nrow = nj)
+  
+  #if(nob > m){
+  #dat = data.frame(data = out, pens = pens)
+  #} else {
+  dat <- out
+  #}
+  
+  return(dat)
+}
+
